==> miesmuschel_0.0.2.tar.gz: miesmuschel/R/bibentries.R <==
#' @importFrom utils bibentry
bibentries = c(
  fieldsend2014rolling = bibentry("article",
    title = "The rolling tide evolutionary algorithm: A multiobjective optimizer for noisy optimization problems",
    author = "Fieldsend, Jonathan E and Everson, Richard M",
    journal = "IEEE Transactions on Evolutionary Computation",
    volume = "19",
    number = "1",
    pages = "103--117",
    year = "2014",
    publisher = "IEEE"
  ),
  li2013mixed = bibentry("article",
    title = "Mixed integer evolution strategies for parameter optimization",
    author = "Li, Rui and Emmerich, Michael TM and Eggermont, Jeroen and B{\"a}ck, Thomas and Sch{\"u}tz, Martin and Dijkstra, Jouke and Reiber, Johan HC",
    journal = "Evolutionary computation",
    volume = "21",
    number = "1",
    pages = "29--64",
    year = "2013",
    publisher = "MIT Press"
  ),
  deb1995simulated = bibentry("article",
    title = "Simulated binary crossover for continuous search space",
    author = "Deb, Kalyanmoy and Agrawal, Ram Bhushan and others",
    journal = "Complex systems",
    volume = "9",
    number = "2",
    pages = "115--148",
    year = "1995",
    publisher = "Citeseer"
  ),
  knowles2006parego = bibentry("article",
    title = "ParEGO: A hybrid algorithm with on-line landscape approximation for expensive multiobjective optimization problems",
    author = "Knowles, Joshua",
    journal = "IEEE Transactions on Evolutionary Computation",
    volume = "10",
    number = "1",
    pages = "50--66",
    year = "2006",
    publisher = "IEEE"
  )
)

==> miesmuschel_0.0.4.tar.gz: miesmuschel/R/bibentries.R <==
#' @importFrom utils bibentry
bibentries = c(
  fieldsend2014rolling = bibentry("article",
    title = "The rolling tide evolutionary algorithm: A multiobjective optimizer for noisy optimization problems",
    author = "Fieldsend, Jonathan E and Everson, Richard M",
    journal = "IEEE Transactions on Evolutionary Computation",
    volume = "19",
    number = "1",
    pages = "103--117",
    year = "2014",
    publisher = "IEEE"
  ),
  li2013mixed = bibentry("article",
    title = "Mixed integer evolution strategies for parameter optimization",
    author = "Li, Rui and Emmerich, Michael TM and Eggermont, Jeroen and B{\"a}ck, Thomas and Sch{\"u}tz, Martin and Dijkstra, Jouke and Reiber, Johan HC",
    journal = "Evolutionary computation",
    volume = "21",
    number = "1",
    pages = "29--64",
    year = "2013",
    publisher = "MIT Press"
  ),
  deb1995simulated = bibentry("article",
    title = "Simulated binary crossover for continuous search space",
    author = "Deb, Kalyanmoy and Agrawal, Ram Bhushan and others",
    journal = "Complex systems",
    volume = "9",
    number = "2",
    pages = "115--148",
    year = "1995",
    publisher = "Citeseer"
  ),
  knowles2006parego = bibentry("article",
    title = "ParEGO: A hybrid algorithm with on-line landscape approximation for expensive multiobjective optimization problems",
    author = "Knowles, Joshua",
    journal = "IEEE Transactions on Evolutionary Computation",
    volume = "10",
    number = "1",
    pages = "50--66",
    year = "2006",
    publisher = "IEEE"
  ),
  chan2013klee = bibentry("inproceedings",
    title = "Klee's measure problem made easy",
    author = "Chan, Timothy M",
    booktitle = "2013 IEEE 54th annual symposium on foundations of computer science",
    pages = "410--419",
    year = "2013",
    organization = "IEEE"
  )
)
